import express, { Router } from 'express';
import 'express-async-errors';
import 'dotenv/config';
import './utils/db';
import cors from 'cors';
import { corsConfig } from './config/cors.config';
import { usersRouter } from './routes/users.routes';
import { handleError } from './utils/handleError';
import cookieParser from 'cookie-parser';
import { credentials } from './middleware/credentials';
import morgan from 'morgan';
import { adsRouter } from './routes/ads.routes';
import { limiter } from './middleware/rateLimit';

const app = express();
const router = Router();

app.use(credentials);
app.use(cors(corsConfig));
app.use(express.json());
app.use(cookieParser());
app.use(morgan('dev'));
app.use(limiter);

router.use('/users', usersRouter);
router.use('/annoucements', adsRouter);

app.use('/api', router);

app.use(handleError);


app.listen(3001, '0.0.0.0', () => {
  console.log('Server is listening on http://localhost:3001');
});
