"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsersController = void 0;
const user_record_1 = require("../records/user.record");
const handleError_1 = require("../utils/handleError");
const bcrypt_1 = require("bcrypt");
const jsonwebtoken_1 = require("jsonwebtoken");
class UsersController {
    static register(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const userReq = req.body;
            const user = new user_record_1.UserRecord(userReq);
            yield user.insert();
            res.status(201).json(user.email);
        });
    }
    static login(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const loginUserReq = req.body;
            if (!loginUserReq.email || !loginUserReq.password) {
                throw new handleError_1.CustomError('Email and password are required.', 400);
            }
            const user = yield user_record_1.UserRecord.getOneByEmail(loginUserReq.email);
            if (!user)
                throw new handleError_1.CustomError('Wrong email or password.', 400);
            const match = yield (0, bcrypt_1.compare)(loginUserReq.password, user.password);
            if (!match)
                throw new handleError_1.CustomError('Wrong email or password.', 400);
            const refreshToken = (0, jsonwebtoken_1.sign)({ id: user.id }, process.env.REFRESH_TOKEN_SECRET, { expiresIn: '365d' });
            const accessToken = (0, jsonwebtoken_1.sign)({ id: user.id }, process.env.ACCESS_TOKEN_SECRET, { expiresIn: '15min' });
            user.refreshToken = refreshToken;
            yield user.update();
            res.cookie('__refresh', refreshToken, {
                httpOnly: true,
                secure: true,
                sameSite: 'none',
                maxAge: 365 * 24 * 60 * 60 * 1000,
            });
            res.status(200).json({ id: user.id, username: user.username, accessToken });
        });
    }
    static logout(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const { id } = req.body;
            if (!id)
                throw new Error('Id not sent from frontend app.');
            const user = yield user_record_1.UserRecord.getOneById(id);
            user.refreshToken = null;
            yield user.update();
            res.clearCookie('__refresh', { httpOnly: true, sameSite: 'none', secure: true });
            res.sendStatus(200);
        });
    }
    static refresh(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const refreshToken = req.cookies['__refresh'];
            if (!refreshToken)
                throw new handleError_1.CustomError('Unauthorized', 401);
            const { id } = (0, jsonwebtoken_1.verify)(refreshToken, process.env.REFRESH_TOKEN_SECRET);
            const user = yield user_record_1.UserRecord.getOneById(id);
            if ((user === null || user === void 0 ? void 0 : user.refreshToken) !== refreshToken)
                throw new handleError_1.CustomError('Forbidden', 403);
            const accessToken = (0, jsonwebtoken_1.sign)({ id }, process.env.ACCESS_TOKEN_SECRET, { expiresIn: '15min' });
            res.status(200).json(accessToken);
        });
    }
}
exports.UsersController = UsersController;
//# sourceMappingURL=users.controller.js.map