"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
require("express-async-errors");
require("dotenv/config");
require("./utils/db");
const cors_1 = __importDefault(require("cors"));
const cors_config_1 = require("./config/cors.config");
const users_routes_1 = require("./routes/users.routes");
const handleError_1 = require("./utils/handleError");
const cookie_parser_1 = __importDefault(require("cookie-parser"));
const credentials_1 = require("./middleware/credentials");
const morgan_1 = __importDefault(require("morgan"));
const ads_routes_1 = require("./routes/ads.routes");
const rateLimit_1 = require("./middleware/rateLimit");
const app = (0, express_1.default)();
app.use(credentials_1.credentials);
app.use((0, cors_1.default)(cors_config_1.corsConfig));
app.use(express_1.default.json());
app.use((0, cookie_parser_1.default)());
app.use((0, morgan_1.default)('dev'));
app.use(rateLimit_1.limiter);
app.use('/users', users_routes_1.usersRouter);
app.use('/ads', ads_routes_1.adsRouter);
app.use(handleError_1.handleError);
app.listen(3001, '0.0.0.0', () => {
    console.log('Server is listening on http://localhost:3001');
});
//# sourceMappingURL=index.js.map