"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const handleError_1 = require("../utils/handleError");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class AdRecord {
    constructor(obj) {
        var _a, _b;
        this.id = obj.id;
        this.userId = obj.userId;
        this.title = (_a = obj.title) === null || _a === void 0 ? void 0 : _a.trim();
        this.description = (_b = obj.description) === null || _b === void 0 ? void 0 : _b.trim();
        this.price = obj.price;
        this.url = obj.url;
        this.lat = obj.lat;
        this.lng = obj.lng;
        this.createdAt = obj.createdAt;
        this.username = obj.username;
        this.validate();
    }
    validate() {
        if (!this.title) {
            throw new handleError_1.CustomError('Title is required');
        }
        if (this.price === undefined) {
            throw new handleError_1.CustomError('Price is required');
        }
        if (!this.url) {
            throw new handleError_1.CustomError('Link is required');
        }
        if (this.title.length < 5 || this.title.length > 70) {
            throw new handleError_1.CustomError('Title must be longer than 5 characters and shorter than 70.');
        }
        if (this.description.length > 300) {
            throw new handleError_1.CustomError('Description cannot be longer than 300 characters.');
        }
        if (typeof this.price !== 'number') {
            throw new handleError_1.CustomError('Price must be a number.');
        }
        if (this.price < 0) {
            throw new handleError_1.CustomError('Price cannot be lower than 0.');
        }
        if (this.price > 99999999) {
            throw new handleError_1.CustomError('I think that You want too much for your thing.');
        }
        if (this.url.length > 500) {
            throw new handleError_1.CustomError('Link cannot be longer than 500 characters.');
        }
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            this.id = (0, uuid_1.v4)();
            this.createdAt = new Date();
            yield db_1.pool.execute('INSERT INTO `ads` VALUES(:id, :userId, :title, :description, :price, :url, :lat, :lng, :createdAt)', this);
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('UPDATE `ads` SET `title` = :title, `description` = :description, `price` = :price, `url` = :url WHERE `id` = :id', this);
        });
    }
    static searchAll(term) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT `id`, `userId`, `lat`, `lng` FROM `ads` WHERE `title` LIKE :term', {
                term: `%${term}%`,
            });
            return res;
        });
    }
    static getOneById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [res] = yield db_1.pool.execute('SELECT `ads`.`id`, `ads`.`userId`,`ads`.`title`,`ads`.`description`,`ads`.`price`,`ads`.`url`,`ads`.`lat`,`ads`.`lng`,`ads`.`createdAt`, `users`.`username`  FROM `ads` JOIN `users` ON `ads`.`userId` = `users`.`id` WHERE `ads`.`id` = :id', { id });
            return res.length === 0 ? null : new AdRecord(res[0]);
        });
    }
    static deleteOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `ads` WHERE `id` = :id', { id });
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map